@@ -1,8 +1,8 @@
 #' 
 #' \code{catalog2pdf} combines \code{\link{catalog}} images into pdfs 
-#' @usage catalog2pdf(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path = NULL, 
+#' @usage catalog2pdf(keep.img = TRUE, overwrite = FALSE, parallel = 1, path = NULL, 
 #' pb = TRUE, by.img.suffix = FALSE, ...)
-#' @param keep.jpeg Logical argument. Indicates whether jpeg files should be kept (default) or remove.
+#' @param keep.img Logical argument. Indicates whether jpeg files should be kept (default) or remove.
 #'   (including sound file and page number) should be magnified. Default is 1.
 #' @param overwrite Logical argument. If \code{TRUE} all jpeg pdf will be produced again 
 #'   when code is rerun. If \code{FALSE} only the ones missing will be produced. Default is \code{FALSE}.
@@ -20,7 +20,7 @@
 #' @name catalog2pdf
 #' @details The function combines catalog images in .jpeg format from the \code{\link{catalog}} function into pdfs. Note that using lower resolution and smaller dimension (width and height) when creating catalogs will substantially decrease the size of pdf files (which could be pretty big).
 #' @seealso \code{\link{catalog2pdf}}, 
-#' \url{https://marce10.github.io/2017-03-17-Creating_song_catalogs/}
+#' \url{https://marce10.github.io/2017/03/17/Creating_song_catalogs.html}
 #' @examples
 #' \dontrun{
 #' # Set temporary working directory
@@ -33,30 +33,33 @@
 #' 
 #' catalog(X = selec.table, nrow = 2, ncol = 4)
 #' 
-#' #now create single pdf removing jpeg
-#' catalog2pdf(keep.jpeg = FALSE)
+#' # now create single pdf removing jpeg
+#' catalog2pdf(keep.img = FALSE)
 #' 
-#' check this floder
+#' # check this floder
 #' getwd()
 #' }
 #' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu})
 #last modification on nov-13-2016 (MAS)
 
-catalog2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path = NULL, 
+catalog2pdf <- function(keep.img = TRUE, overwrite = FALSE, parallel = 1, path = NULL, 
                         pb = TRUE, by.img.suffix = FALSE, ...)
 {
+  # reset working directory 
+  wd <- getwd()
+  on.exit(setwd(wd))
+  
   #check path to working directory
-  if(!is.null(path))
-  {wd <- getwd()
-    if(class(try(setwd(path), silent = TRUE)) == "try-error") stop("'path' provided does not exist") else 
-  setwd(path)} #set working directory
+  if(is.null(path)) path <- getwd() else {if(!file.exists(path)) stop("'path' provided does not exist") else
+    setwd(path)
+  }  
   
   #list jpeg files
   imgs <- list.files(pattern = "\\.jpeg$", ignore.case = TRUE)
   if(length(imgs) == 0) stop("No .jpeg files were found in the working directory")
   
   #remove images that don't have the catalog_pX.jpeg ending
-  imgs <- grep(paste("Catalog_p\\d+\\.jpeg"),imgs, value = TRUE)
+  imgs <- grep("Catalog_p\\d+", imgs, value = TRUE)
     
   #remove page info at the end of file names to get sound file names
  if(by.img.suffix)
@@ -74,7 +77,7 @@ catalog2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path
   
   #loop over each sound file name  
   # no.out <- parallel::mclapply(unique(or.sf), mc.cores = parallel, function(x)
-    cat2pdfFUN <- function(i, overwrite, keep.jpeg)
+    cat2pdfFUN <- function(i, overwrite, keep.img)
     {
       if(!is.logical(i)) filnam <- paste0(i, ".pdf") else filnam <- "Catalog.pdf"
    
@@ -120,7 +123,7 @@ catalog2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path
       })
     }
     dev.off()
-  if(!keep.jpeg) unlink(subimgs)
+  if(!keep.img) unlink(subimgs)
     }
     }
     # )
@@ -137,7 +140,7 @@ catalog2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path
       doParallel::registerDoParallel(cl)
       
       lst <- foreach::foreach(i = unique(or.sf)) %dopar% {
-        cat2pdfFUN(i, overwrite, keep.jpeg)
+        cat2pdfFUN(i, overwrite, keep.img)
       }
       
       parallel::stopCluster(cl)
@@ -147,11 +150,11 @@ catalog2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path
       
       if(pb)
       lst <- pbmcapply::pbmclapply(unique(or.sf), mc.cores = parallel,function (i) {
-        cat2pdfFUN(i, overwrite, keep.jpeg)
+        cat2pdfFUN(i, overwrite, keep.img)
       }) else
       
       lst <- parallel::mclapply(unique(or.sf), mc.cores = parallel, function (i) {
-        cat2pdfFUN(i, overwrite, keep.jpeg)
+        cat2pdfFUN(i, overwrite, keep.img)
       })
     }
     if(!any(Sys.info()[1] == c("Linux", "Windows"))) # parallel in OSX
@@ -161,7 +164,7 @@ catalog2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path
       doParallel::registerDoParallel(cl)
       
       lst <- foreach::foreach(i = unique(or.sf)) %dopar% {
-        cat2pdfFUN(i, overwrite, keep.jpeg)
+        cat2pdfFUN(i, overwrite, keep.img)
       }
       
       parallel::stopCluster(cl)
@@ -169,8 +172,7 @@ catalog2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path
     }
   } else 
     if(pb)
-    lst <- pbapply::pblapply(unique(or.sf), function(i) cat2pdfFUN(i, overwrite, keep.jpeg)) else
-      lst <- lapply(unique(or.sf), function(i) cat2pdfFUN(i, overwrite, keep.jpeg))
+    lst <- pbapply::pblapply(unique(or.sf), function(i) cat2pdfFUN(i, overwrite, keep.img)) else
+      lst <- lapply(unique(or.sf), function(i) cat2pdfFUN(i, overwrite, keep.img))
   
-  if(!is.null(path)) setwd(wd)
 }
