@@ -2,9 +2,9 @@
 #' 
 #' \code{checksels} checks whether selections can be read by subsequent functions.
 #' @usage checksels(X, parallel =  1, path = NULL, check.header = FALSE)
-#' @param X data frame with the following columns: 1) "sound.files": name of the .wav 
+#' @param X 'selection.table' object or data frame with the following columns: 1) "sound.files": name of the .wav 
 #' files, 2) "sel": number of the selections, 3) "start": start time of selections, 4) "end": 
-#' end time of selections. The ouptut of \code{\link{manualoc}} or \code{\link{autodetec}} can 
+#' end time of selections. Alternatively, a 'selection.table' class object can be input to double check selections. The ouptut of \code{\link{manualoc}} or \code{\link{autodetec}} can 
 #' be used as the input data frame.
 #' @param parallel Numeric. Controls whether parallel computing is applied.
 #'  It specifies the number of cores to be used. Default is 1 (i.e. no parallel computing).
@@ -26,8 +26,7 @@
 #' @seealso \code{\link{checkwavs}}
 #' @export
 #' @name checksels
-#' @examples
-#' \dontrun{
+#' @examples{
 #' # First set temporary folder
 #' setwd(tempdir())
 #' 
@@ -44,38 +43,70 @@
 
 checksels <- function(X = NULL, parallel =  1, path = NULL, check.header = FALSE){
   
+  # reset working directory 
+  wd <- getwd()
+  on.exit(setwd(wd))
+  
+  
   #check path to working directory
-  if(!is.null(path))
-  {wd <- getwd()
-  if(class(try(setwd(path), silent = TRUE)) == "try-error") stop("'path' provided does not exist") else 
-    setwd(path)} #set working directory
+  if(is.null(path)) path <- getwd() else {if(!file.exists(path)) stop("'path' provided does not exist") else
+    setwd(path)
+  }  
   
   #if X is not a data frame
-  if(!class(X) == "data.frame") stop("X is not a data frame")
-  
+  if(!class(X) %in% c("data.frame", "selection.table")) stop("X is not of a class 'data.frame' or 'selection table")
+
   if(!all(c("sound.files", "selec", 
             "start", "end") %in% colnames(X))) 
     stop(paste(paste(c("sound.files", "selec", "start", "end")[!(c("sound.files", "selec", 
                                                                    "start", "end") %in% colnames(X))], collapse=", "), "column(s) not found in data frame"))
+
+  #if end or start are not numeric stop
+  if(all(class(X$end) != "numeric" & class(X$start) != "numeric")) stop("'end' and 'selec' must be numeric")
+  
+  #if there are NAs in start or end stop
+  if(any(is.na(c(X$end, X$start)))) stop("NAs found in start and/or end")  
+  
+  if(any(duplicated(paste(X$sound.files, X$selec)))) stop("Duplicated selection labels for one or more sound files")
+  
+  
+  #if any start higher than end stop
+  if(any(X$end - X$start < 0)) stop(paste("The start is higher than the end in", length(which(X$end - X$start < 0)), "case(s)"))  
+  
+  #check additional columns
+  if(!"channel" %in% colnames(X)) 
+  {#cat("\n sound file channel for analysis assumed to be 1 (left) for all selections (channel column not found)")
+    X$channel <- 1
+  } else {
+    if(!is.numeric(X$channel)) stop("'channel' must be numeric")
+    if(any(is.na(X$channel))) {cat("NAs in 'channel', assumed to be channel 1")
+      X$channel[is.na(X$channel)] <- 1   
+    }}
   
   #check if files are in working directory
   files <- list.files(pattern = "wav$", ignore.case = TRUE)
   if (length(files) == 0) 
     stop("no .wav files in working directory")
   
-  #if there are NAs in start or end stop
-  if(any(is.na(c(X$end, X$start)))) stop("NAs found in start and/or end")  
-  
-  #if end or start are not numeric stop
-  if(all(class(X$end) != "numeric" & class(X$start) != "numeric")) stop("'end' and 'selec' must be numeric")
-  
-  #if any start higher than end stop
-  if(any(X$end - X$start<0)) stop(paste("The start is higher than the end in", length(which(X$end - X$start<0)), "case(s)"))  
-  
   #if any selection labels are repeated within a sound file
   if(length(unique(paste(X$sound.files, X$selec))) != nrow(X))
  stop("Repeated selection labels within (a) sound file(s)")  
   
+  
+  # update to new frequency range column names
+  if(any(grepl("low.freq|high.freq", names(X)))) { 
+    names(X)[names(X) == "low.freq"] <- "bottom.freq"
+    names(X)[names(X) == "high.freq"] <- "top.freq"
+  }
+  
+  #check frequency range columns
+  if("top.freq" %in% colnames(X)) 
+  {
+    #if any start higher than end stop
+    if(any(X$top.freq - X$bottom.freq < 0)) stop(paste("The bottom frequency is higher than the top frequency in", length(which(X$top.freq - X$bottom.freq < 0)), "case(s)"))  
+    if(any(X$bottom.freq < 0)) stop("bottom frequency lower than 0 for some selections")  
+  }    
+  
     #function to run over each sound file
   csFUN <- function(x, X){
     Y <- X[X$sound.files == x, ]
@@ -88,8 +119,19 @@ checksels <- function(X = NULL, parallel =  1, path = NULL, check.header = FALSE
         if(check.header)  
         {
           recfull <- try(suppressWarnings(tuneR::readWave(as.character(x), header = FALSE)), silent = TRUE)
-          if(any(rec$sample.rate != recfull@samp.rate, !all.equal(rec$channels == 2, 
-            recfull@stereo), rec$bits != recfull@bit, rec$samples != length(recfull@left)))
+          if(any(methods::slotNames(recfull) == "stereo")) 
+          {
+            if(rec$channels == 2) channel.check <- ifelse(recfull@stereo, FALSE, TRUE) else
+              channel.check <- ifelse(!recfull@stereo, FALSE, TRUE)
+            
+            samples.check <- ifelse(rec$samples == length(recfull@left), FALSE, TRUE) 
+          } else {
+            channel.check <- FALSE
+            samples.check <- ifelse(rec$samples == length(recfull@.Data), FALSE, TRUE)
+          }
+          
+            
+          if(any(rec$sample.rate != recfull@samp.rate, rec$bits != recfull@bit, channel.check, samples.check))
           {
           Y$check.res <- "file header corrupted"
           Y$duration <- NA
@@ -189,8 +231,15 @@ checksels <- function(X = NULL, parallel =  1, path = NULL, check.header = FALSE
   }    
   res <- do.call(rbind, a1)
   res <- res[match(paste(X$sound.files, X$selec), paste(res$sound.files, res$selec)),]
-  return(res)  
-  if(!is.null(path)) setwd(wd)
+  
+  if("top.freq" %in% names(res))
+  if(any((((res$sample.rate[!is.na(res$duration)])/2000) - res$top.freq[!is.na(res$duration)]) < 0)) stop("top frequency can't be higher than half the sample rate")  
+  if(any(res$channel[!is.na(res$duration)] > res$channels[!is.na(res$duration)])) {cat("\n some selections for channel 2 in sound files with only 1 channel, relabeled as channel 1") 
+    res$channel[!is.na(res$duration)][any(res$channel[!is.na(res$duration)] > res$channels[!is.na(res$duration)])] <- 1
+  }
+  
+    return(res)  
+
 }
 
 
