@@ -2,28 +2,37 @@
 #' 
 #' \code{dfDTW} calculates acoustic dissimilarity of dominant frequency contours using dynamic
 #' time warping. Internally it applies the \code{\link[dtw]{dtwDist}} function from the \code{dtw} package.
-#' @usage dfDTW(X, wl = 512, length.out = 20, wn = "hanning", ovlp = 70, bp = c(0, 22),
-#'   threshold = 5, img = TRUE, parallel = 1, path = NULL, img.suffix = "dfDTW", pb = TRUE, 
-#'   clip.edges = TRUE, window.type = "none", open.end = FALSE, scale = FALSE, ...)
-#' @param  X Data frame with results containing columns for sound file name (sound.files), 
+#' @usage dfDTW(X = NULL, wl = 512, wl.freq = 512, length.out = 20, wn = "hanning", ovlp = 70, 
+#' bp = c(0, 22), threshold = 15, threshold.time = NULL, threshold.freq = NULL, img = TRUE, 
+#' parallel = 1, path = NULL, ts.df = NULL, img.suffix = "dfDTW", pb = TRUE, 
+#' clip.edges = TRUE, window.type = "none", open.end = FALSE, scale = FALSE, 
+#' frange.detec = FALSE,  fsmooth = 0.1, ...)
+#' @param  X 'selection.table' object or data frame with results containing columns for sound file name (sound.files), 
 #' selection number (selec), and start and end time of signal (start and end).
 #' The ouptut of \code{\link{manualoc}} or \code{\link{autodetec}} can be used as the input data frame. 
 #' @param wl A numeric vector of length 1 specifying the window length of the spectrogram, default 
 #'   is 512.
-#' @param length.out A character vector of length 1 giving the number of measurements of dominant 
+#' @param length.out A numeric vector of length 1 giving the number of measurements of dominant 
 #' frequency desired (the length of the time series).
 #' @param wn Character vector of length 1 specifying window name. Default is 
 #'   "hanning". See function \code{\link[seewave]{ftwindow}} for more options.
+#' @param wl.freq A numeric vector of length 1 specifying the window length of the spectrogram
+#' for measurements on the frecuency spectrum. Default is 512. Higher values would provide 
+#' more accurate measurements.
 #' @param ovlp Numeric vector of length 1 specifying \% of overlap between two 
 #'   consecutive windows, as in \code{\link[seewave]{spectro}}. Default is 70. 
 #' @param bp A numeric vector of length 2 for the lower and upper limits of a 
 #'   frequency bandpass filter (in kHz). Default is c(0, 22).
-#' @param threshold amplitude threshold (\%) for dominant frequency detection. Default is 5.
+#' @param threshold amplitude threshold (\%) for dominant frequency detection. Default is 15.
+#' @param threshold.time amplitude threshold (\%) for the time domain. Use for fundamental and dominant frequency detection. If \code{NULL} (default) then the 'threshold' value is used.
+#' @param threshold.freq amplitude threshold (\%) for the frequency domain. Use for frequency range detection from the spectrum (see 'frange.detec'). If \code{NULL} (default) then the
+#'  'threshold' value is used.
 #' @param img Logical argument. If \code{FALSE}, image files are not produced. Default is \code{TRUE}.
 #' @param parallel Numeric. Controls whether parallel computing is applied.
 #'  It specifies the number of cores to be used. Default is 1 (i.e. no parallel computing). Not availble in Windows OS.
 #' @param path Character string containing the directory path where the sound files are located. 
 #' If \code{NULL} (default) then the current working directory is used.
+#' @param ts.df Optional. Data frame with time series of signals to be compared. If provided "X" is ignored.  
 #' @param img.suffix A character vector of length 1 with a suffix (label) to add at the end of the names of 
 #' image files. Default is \code{NULL}.
 #' @param pb Logical argument to control progress bar. Default is \code{TRUE}. Note that progress bar is only used
@@ -37,6 +46,12 @@
 #' open-ended alignments (see \code{\link[dtw]{dtw}}).
 #' @param scale Logical. If \code{TRUE} dominant frequency values are z-transformed using the \code{\link[base]{scale}} function, which "ignores" differences in absolute frequencies between the signals in order to focus the 
 #' comparison in the frequency contour, regardless of the pitch of signals. Default is \code{TRUE}.
+#' @param frange.detec Logical. Controls whether frequency range of signal is automatically 
+#' detected  using the \code{\link{frange.detec}} function. If so, the range is used as the 
+#' bandpass filter (overwriting 'bp' argument). Default is \code{FALSE}.
+#' @param fsmooth A numeric vector of length 1 to smooth the frequency spectrum with a mean
+#'  sliding window (in kHz) used for frequency range detection (when \code{frange.detec = TRUE}). This help to average amplitude "hills" to minimize the effect of
+#'  amplitude modulation. Default is 0.1. 
 #' @param ... Additional arguments to be passed to \code{\link{trackfreqs}} for customizing
 #' graphical output.
 #' @return A matrix with the pairwise dissimilarity values. If img is 
@@ -46,7 +61,7 @@
 #' @seealso \code{\link{specreator}} for creating spectrograms from selections,
 #'  \code{\link{snrspecs}} for creating spectrograms to 
 #'   optimize noise margins used in \code{\link{sig2noise}} and \code{\link{dfts}}, \code{\link{ffts}}, \code{\link{ffDTW}} for frequency contour overlaid spectrograms.
-#'  \url{https://marce10.github.io/2016-09-12-Similarity_of_acoustic_signals_with_dynamic_time_warping_(DTW)/}
+#'  \url{https://marce10.github.io/2016/09/12/Similarity_of_acoustic_signals_with_dynamic_time_warping_(DTW).html}
 #' @export
 #' @name dfDTW
 #' @details This function extracts the dominant frequency values as a time series and
@@ -55,8 +70,7 @@
 #'  frequency  measures. If 'img' is  \code{TRUE} the function also produces image files
 #'  with the spectrograms of the signals listed in the input data frame showing the
 #'  location of the dominant frequencies.
-#' @examples
-#' \dontrun{
+#' @examples{
 #' # set the temp directory
 #' setwd(tempdir())
 #' 
@@ -72,19 +86,43 @@
 #' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu})
 #last modification on nov-31-2016 (MAS)
 
-dfDTW <-  function(X, wl = 512, length.out = 20, wn = "hanning", ovlp = 70, 
-           bp = c(0, 22), threshold = 5, img = TRUE, parallel = 1, path = NULL, 
+dfDTW <-  function(X = NULL, wl = 512, wl.freq = 512, length.out = 20, wn = "hanning", ovlp = 70, 
+           bp = c(0, 22), threshold = 15, threshold.time = NULL, threshold.freq = NULL, 
+           img = TRUE, parallel = 1, path = NULL, ts.df = NULL,
            img.suffix = "dfDTW", pb = TRUE, clip.edges = TRUE, 
-           window.type = "none", open.end = FALSE, scale = FALSE, ...){     
- 
+           window.type = "none", open.end = FALSE, scale = FALSE, frange.detec = FALSE,
+           fsmooth = 0.1, ...){     
+  
+  if(is.null(X) & is.null(ts.df)) stop("either 'X' or 'ts.df' should be provided")
+
+  if(!is.null(X)) {
+    #if X is not a data frame
+    if(!class(X) %in% c("data.frame", "selection.table")) stop("X is not of a class 'data.frame' or 'selection table")
+    
+    
+  }
+  
   #stop if only 1 selection
-  if(nrow(X) == 1) stop("you need more than one selection for dfDTW")
+  if(is.null(ts.df)) {if(nrow(X) == 1) stop("you need more than one selection for dfDTW")
+  
+  # threshold adjustment
+  if(is.null(threshold.time)) threshold.time <- threshold
+  if(is.null(threshold.freq)) threshold.freq <- threshold
   
   #run dfts function
-  res <- dfts(X, wl = wl, length.out = length.out, wn = wn, ovlp = ovlp, 
-              bp = bp, threshold = threshold, img = img, parallel = parallel,
-              path = path, img.suffix = img.suffix, pb = pb, clip.edges = clip.edges, ...)
+  res <- dfts(X, wl = wl, length.out = length.out, wn = wn, ovlp = ovlp, wl.freq = wl.freq,
+              bp = bp, threshold.time = threshold.time, threshold.freq = threshold.freq, 
+              img = img, parallel = parallel,
+              path = path, img.suffix = img.suffix, pb = pb, clip.edges = clip.edges, fsmooth = fsmooth, frange.detec = frange.detec, ...)
+  } else {
+    
+    if(!all(c("sound.files", "selec") %in% names(ts.df))) 
+      stop(paste(paste(c("sound.files", "selec")[!(c("sound.files", "selec") %in% names(ts.df))], collapse=", "), "column(s) not found in ts.df"))
+    
+    res <- ts.df
+  }
   
+
   
     #matrix of dom freq time series
   mat <- res[,3:ncol(res)]
@@ -93,7 +131,7 @@ dfDTW <-  function(X, wl = 512, length.out = 20, wn = "hanning", ovlp = 70,
   mat <- t(apply(mat, 1, scale))  
 
   #stop if NAs in matrix
-  if(any(is.na(mat))) stop("missing values in frequency time series (fundamental frequency was not detected at
+  if(any(is.na(mat))) stop("missing values in time series (frequency was not detected at
                            the start and/or end of the signal)")
   
   dm <- dtw::dtwDist(mat, mat, window.type = window.type, open.end = open.end)    
