@@ -1,8 +1,8 @@
 # Combine lspec images to single pdf files
 #' 
 #' \code{lspec2pdf} combines \code{\link{lspec}} images in .jpeg format to a single pdf file. 
-#' @usage lspec2pdf(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path = NULL, pb = TRUE)
-#' @param keep.jpeg Logical argument. Indicates whether jpeg files should be kept (default) or remove.
+#' @usage lspec2pdf(keep.img = TRUE, overwrite = FALSE, parallel = 1, path = NULL, pb = TRUE)
+#' @param keep.img Logical argument. Indicates whether jpeg files should be kept (default) or remove.
 #'   (including sound file and page number) should be magnified. Default is 1.
 #' @param overwrite Logical argument. If \code{TRUE} all jpeg pdf will be produced again 
 #'   when code is rerun. If \code{FALSE} only the ones missing will be produced. Default is \code{FALSE}.
@@ -31,15 +31,15 @@
 #' lspec(sxrow = 2, rows = 8, pal = reverse.heat.colors, wl = 300, it = "jpeg")
 #' 
 #' #now create single pdf removing jpeg
-#' lspec2pdf(keep.jpeg = FALSE)
+#' lspec2pdf(keep.img = FALSE)
 #' 
-#' check this floder
+#' # check this floder
 #' getwd()
 #' }
 #' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu})
 #last modification on nov-13-2016 (MAS)
 
-lspec2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path = NULL, pb = TRUE)
+lspec2pdf <- function(keep.img = TRUE, overwrite = FALSE, parallel = 1, path = NULL, pb = TRUE)
 {
   #check path to working directory
   if(!is.null(path))
@@ -66,7 +66,7 @@ lspec2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path =
 
   #loop over each sound file name  
   # no.out <- parallel::mclapply(unique(or.sf), mc.cores = parallel, function(x)
-    l2pdfFUN <- function(i, overwrite, keep.jpeg)
+    l2pdfFUN <- function(i, overwrite, keep.img)
     {
     if(any(!overwrite & !file.exists(paste0(i, ".pdf")), overwrite))
 {    pdf(file = paste0(i, ".pdf"), width = 8.5, height = 11)
@@ -98,7 +98,7 @@ lspec2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path =
       })
     }
     dev.off()
-  if(!keep.jpeg) unlink(subimgs)
+  if(!keep.img) unlink(subimgs)
     }
     }
     # )
@@ -115,7 +115,7 @@ lspec2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path =
       doParallel::registerDoParallel(cl)
       
       lst <- foreach::foreach(i = unique(or.sf)) %dopar% {
-        l2pdfFUN(i, overwrite, keep.jpeg)
+        l2pdfFUN(i, overwrite, keep.img)
       }
       
       parallel::stopCluster(cl)
@@ -125,11 +125,11 @@ lspec2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path =
       
       if(pb)
       lst <- pbmcapply::pbmclapply(unique(or.sf), mc.cores = parallel,function (i) {
-        l2pdfFUN(i, overwrite, keep.jpeg)
+        l2pdfFUN(i, overwrite, keep.img)
       }) else
       
       lst <- parallel::mclapply(unique(or.sf), mc.cores = parallel, function (i) {
-        l2pdfFUN(i, overwrite, keep.jpeg)
+        l2pdfFUN(i, overwrite, keep.img)
       })
     }
     if(!any(Sys.info()[1] == c("Linux", "Windows"))) # parallel in OSX
@@ -139,7 +139,7 @@ lspec2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path =
       doParallel::registerDoParallel(cl)
       
       lst <- foreach::foreach(i = unique(or.sf)) %dopar% {
-        l2pdfFUN(i, overwrite, keep.jpeg)
+        l2pdfFUN(i, overwrite, keep.img)
       }
       
       parallel::stopCluster(cl)
@@ -147,8 +147,8 @@ lspec2pdf <- function(keep.jpeg = TRUE, overwrite = FALSE, parallel = 1, path =
     }
   } else 
     if(pb)
-    lst <- pbapply::pblapply(unique(or.sf), function(i) l2pdfFUN(i, overwrite, keep.jpeg)) else
-      lst <- lapply(unique(or.sf), function(i) l2pdfFUN(i, overwrite, keep.jpeg))
+    lst <- pbapply::pblapply(unique(or.sf), function(i) l2pdfFUN(i, overwrite, keep.img)) else
+      lst <- lapply(unique(or.sf), function(i) l2pdfFUN(i, overwrite, keep.img))
   
   if(!is.null(path)) setwd(wd)
 }
