@@ -11,7 +11,7 @@
 #' @details This function returns the duration (in seconds) of sound files.
 #'   
 #' @examples
-#' \dontrun{
+#' {
 #' # Set temporary working directory
 #' setwd(tempdir())
 #' 
@@ -28,11 +28,14 @@
 
 wavdur <- function(files = NULL, path = NULL) { 
   
+  # reset working directory 
+  wd <- getwd()
+  on.exit(setwd(wd))
+  
   #check path to working directory
-  if(!is.null(path))
-  {wd <- getwd()
-  if(class(try(setwd(path), silent = TRUE)) == "try-error") stop("'path' provided does not exist") else 
-    setwd(path)} #set working directory
+  if(is.null(path)) path <- getwd() else {if(!file.exists(path)) stop("'path' provided does not exist") else
+    setwd(path)
+  }  
   
   #stop if files is not a character vector
   if(!is.null(files) & !is.character(files)) stop("'files' must be a character vector")
@@ -49,5 +52,4 @@ wavdur <- function(files = NULL, path = NULL) {
   })
    return(data.frame(sound.files = files, duration = a, row.names = NULL))
 
-    if(!is.null(path)) setwd(wd)
   }
